namespace Eco.Mods.TechTree
{
    using System;
    using System.Collections.Generic;
    using System.ComponentModel;
    using Eco.Gameplay.Blocks;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.Components.Auth;
    using Eco.Gameplay.DynamicValues;
    using Eco.Gameplay.Economy;
    using Eco.Gameplay.Housing;
    using Eco.Gameplay.Interactions;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Minimap;
    using Eco.Gameplay.Objects;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Property;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Gameplay.Pipes.LiquidComponents;
    using Eco.Gameplay.Pipes.Gases;
    using Eco.Gameplay.Systems.Tooltip;
    using Eco.Shared;
    using Eco.Shared.Math;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;
    using Eco.Shared.Utils;
    using Eco.Shared.View;
    using Eco.Shared.Items;
    using Eco.Gameplay.Pipes;
    using Eco.World.Blocks;
    
    [Serialized]    
    [RequireComponent(typeof(PropertyAuthComponent))]
    [RequireComponent(typeof(HousingComponent))]                  
    [RequireComponent(typeof(SolidGroundComponent))]            
    public partial class FuelStationSignObject : 
        WorldObject    
    {
        public override string FriendlyName { get { return "FuelStationSign"; } } 


        protected override void Initialize()
        {
            this.GetComponent<HousingComponent>().Set(FuelStationSignItem.HousingVal);                                



        }

        public override void Destroy()
        {
            base.Destroy();
        }
       
    }

    [Serialized]
    public partial class FuelStationSignItem : WorldObjectItem<FuelStationSignObject>
    {
        public override string FriendlyName { get { return "FuelStationSign"; } } 
        public override string Description  { get { return  "A dining room chair variant"; } }

        static FuelStationSignItem()
        {
            
        }

        [TooltipChildren] public HousingValue HousingTooltip { get { return HousingVal; } }
        [TooltipChildren] public static HousingValue HousingVal { get { return new HousingValue() 
                                                {
                                                    Category = "General",
                                                    Val = 0.5f,                                   
                                                    TypeForRoomLimit = "Seating", 
                                                    DiminishingReturnPercent = 0.9f    
        };}}
    }


    [RequiresSkill(typeof(SteelworkingSkill), 3)]
    public partial class FuelStationSignRecipe : Recipe
    {
        public FuelStationSignRecipe()
        {
            this.Products = new CraftingElement[]
            {
                new CraftingElement<FuelStationSignItem>(),
            };

            this.Ingredients = new CraftingElement[]
            {
                new CraftingElement<SteelItem>(typeof(SteelworkingEfficiencySkill), 100, SteelworkingEfficiencySkill.MultiplicativeStrategy),   
				new CraftingElement<LogItem>(typeof(SteelworkingEfficiencySkill), 100, SteelworkingEfficiencySkill.MultiplicativeStrategy),
            };
            SkillModifiedValue value = new SkillModifiedValue(10, SteelworkingSpeedSkill.MultiplicativeStrategy, typeof(SteelworkingSpeedSkill), Localizer.Do("craft time"));
            SkillModifiedValueManager.AddBenefitForObject(typeof(FuelStationSignRecipe), Item.Get<FuelStationSignItem>().UILink(), value);
            SkillModifiedValueManager.AddSkillBenefit(Item.Get<FuelStationSignItem>().UILink(), value);
            this.CraftMinutes = value;
            this.Initialize("Steel Ceiling Light", typeof(FuelStationSignRecipe));
            CraftingComponent.AddRecipe(typeof(FactoryObject), this);
        }
    }
}